Check if the installed RStudio version is up to date
Source:R/general_check_rstudio.R
check_RStudio.RdThis function checks the current installed version of RStudio against the latest version available online. If the versions do not match, it suggests updating RStudio.
Value
Side effects include printing messages to the console regarding the status of RStudio version.
Note
This function requires internet access to check the latest version of RStudio online. If called outside of RStudio, it will only fetch and display the latest version without comparing. If posit has changed the structure of their webpage and the online version can not be parsed, the function reports this clearly and, when possible, still shows the installed version.