Verifies that a java executable can be located and invoked from the system
shell, by running java -version and checking both that the call succeeds
and that it returns a zero exit status.
Verifies that a java executable can be located and invoked from the system
shell, by running java -version and checking both that the call succeeds
and that it returns a zero exit status.